@@ -1,10 +1,10 @@
 from firstimpression.constants import APIS
 from firstimpression.constants import LOCAL_INTEGRATED_FOLDER
+from firstimpression.constants import NAMELEVEL
 from firstimpression.file import update_directories_api
 from firstimpression.file import check_too_old
 from firstimpression.scala import variables
 from firstimpression.scala import log
-from logging import _nameToLevel
 from firstimpression.api.request import request_json
 import json
 import os
@@ -40,7 +40,7 @@ def run_api():
         with open(JSON_FILE_PATH, 'w') as file:
             json.dump(request_json(URL, params=PARAMS).get('value', [{}]), file)
     else:
-        log(_nameToLevel['INFO'], 'File not old enough to update')
+        log(NAMELEVEL['INFO'], 'File not old enough to update')
 
 def check_api():
     svars = variables()
@@ -50,7 +50,7 @@ def check_api():
 
     if check_too_old(JSON_FILE_PATH, MAX_FILE_AGE):
        svars['skipscript'] = True
-       log(_nameToLevel['WARNING'], 'File to old to run chuck_norris')
+       log(NAMELEVEL['WARNING'], 'File to old to run chuck_norris')
     else:
         svars['skipscript'] = False
         svars['joke'] = get_random_joke(firstname, lastname)
