@@ -2,6 +2,7 @@ from firstimpression.constants import APIS
 from firstimpression.constants import TEMP_FOLDER
 from firstimpression.constants import DUTCH_INDEX
 from firstimpression.constants import LOCAL_INTEGRATED_FOLDER
+from firstimpression.constants import NAMELEVEL
 from firstimpression.file import update_directories_api
 from firstimpression.file import check_too_old
 from firstimpression.file import download_install_media
@@ -12,7 +13,6 @@ from firstimpression.scala import log
 from firstimpression.scala import variables
 from firstimpression.text import remove_emoji
 from firstimpression.api.request import request_json
-from logging import _nameToLevel
 import xml.etree.ElementTree as ET
 import os
 import glob
@@ -73,7 +73,7 @@ def run_api(api_key, page_name, max_minutes, max_characters, max_items):
 
         write_root_to_xml_files(root, xml_temp_path, NAME)        
     else:
-        log(_nameToLevel['INFO'], 'File not old enough to download new info')
+        log(NAMELEVEL['INFO'], 'File not old enough to download new info')
 
 def check_api(page_name, max_minutes):
     svars = variables()
