@@ -2,10 +2,11 @@ from firstimpression.constants import APIS
 from firstimpression.constants import LOCAL_INTEGRATED_FOLDER
 from firstimpression.constants import TEMP_FOLDER
 from firstimpression.constants import DUTCH_INDEX
+from firstimpression.constants import ENGLISH_INDEX
 from firstimpression.constants import PICTURE_FORMATS
 from firstimpression.constants import TAGS_TO_REMOVE
 from firstimpression.constants import REPLACE_DICT
-from firstimpression.file import update_directories_api
+from firstimpression.file import create_directories, update_directories_api
 from firstimpression.file import check_too_old
 from firstimpression.file import write_root_to_xml_files
 from firstimpression.file import download_media
@@ -13,6 +14,8 @@ from firstimpression.file import list_files_dir
 from firstimpression.file import xml_to_root
 from firstimpression.time import change_language
 from firstimpression.time import parse_string_to_string
+from firstimpression.time import parse_date_to_string
+from firstimpression.time import parse_string_to_date
 from firstimpression.rss import get_feed
 from firstimpression.xml import get_attrib_from_element
 from firstimpression.scala import install_content
@@ -55,7 +58,6 @@ def run_api(news_categories, minimal_items):
     minimal_items = MAX_ITEMS if minimal_items > MAX_ITEMS else minimal_items
     
     update_directories_api(NAME)
-    change_language(DUTCH_INDEX)
 
     for news_category in news_categories:
         if news_category == '' or news_category is None:
@@ -65,6 +67,8 @@ def run_api(news_categories, minimal_items):
 
         url = BASE_URL + category
 
+        create_directories([os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, category), os.path.join(TEMP_FOLDER, NAME, category)])
+
         xml_temp_path = os.path.join(TEMP_FOLDER, NAME, '{}.xml'.format(category))
 
         if check_too_old(xml_temp_path, MAX_FILE_AGE):
@@ -76,8 +80,8 @@ def run_api(news_categories, minimal_items):
                 item = ET.SubElement(root, "item")
                 ET.SubElement(item, "title").text = replace_html_entities(REPLACE_DICT, get_title(news_item))
                 ET.SubElement(item, "descr").text = remove_tags_from_string(TAGS_TO_REMOVE, get_description(news_item))
-                ET.SubElement(item, "pubDate").text = parse_string_to_string(get_publication_date(news_item), DATETIME_FORMAT, DATETIME_ABREVIATION_FORMAT)
-                ET.SubElement(item, "fullMonthPubDate").text = parse_string_to_string(get_publication_date(news_item), DATETIME_FORMAT, DATETIME_FULL_FORMAT)
+                ET.SubElement(item, "pubDate").text = parse_date_to_string(get_publication_date(news_item), DATETIME_ABREVIATION_FORMAT)
+                ET.SubElement(item, "fullMonthPubDate").text = parse_date_to_string(get_publication_date(news_item), DATETIME_FULL_FORMAT)
 
                 media_link_full = install_picture_content_wrap('fullscreen', os.path.join(NAME, category), TEMP_FOLDER, news_item, 'enclosure', 'url')
                 media_link_sqr = install_picture_content_wrap('square', os.path.join(NAME, category), TEMP_FOLDER, news_item, 'enclosure', 'url')
@@ -144,10 +148,13 @@ def get_description(news_item):
 
 def get_publication_date(news_item):
     time = news_item.findtext(TAGS['pubDate'], None)
+    change_language(ENGLISH_INDEX)
     if time is None:
         return ''
     else:
-        return time[:-5]
+        date = parse_string_to_date(time[:-5], DATETIME_FORMAT)
+        change_language(DUTCH_INDEX)
+        return date
 
 ##################################################################################################
 # PARSE FUNCTIONS
